@@ -523,7 +523,7 @@ class VMUtilsTestCase(test_base.OsWinBaseTestCase):
         expected_serial = mock_phys_disk.ElementName
         expected_mapping = {
             expected_serial: {
-                'resource_path': mock_phys_disk.Path_.return_value,
+                'resource_path': mock_phys_disk.path_.return_value,
                 'mounted_disk_path': mock_phys_disk.HostResource[0]
             }
         }
@@ -543,7 +543,7 @@ class VMUtilsTestCase(test_base.OsWinBaseTestCase):
         self._vmutils._jobutils.modify_virt_resource.assert_called_once_with(
             mock_diskdrive)
 
-        mock_get_wmi_obj.assert_called_once_with(self._FAKE_RES_PATH)
+        mock_get_wmi_obj.assert_called_once_with(self._FAKE_RES_PATH, True)
         self.assertEqual(mock_diskdrive.HostResource,
                          [self._FAKE_MOUNTED_DISK_PATH])
 
@@ -570,15 +570,19 @@ class VMUtilsTestCase(test_base.OsWinBaseTestCase):
             mock_rasds[0].HostResource[0])
 
     def test_take_vm_snapshot(self):
-        self._lookup_vm()
+        mock_vm = self._lookup_vm()
+        mock_snap = mock.MagicMock(Antecedent=mock_vm)
+        self._vmutils._conn.Msvm_MostCurrentSnapshotInBranch.return_value = [
+            mock.MagicMock(), mock_snap]
 
         mock_svc = self._get_snapshot_service()
         mock_svc.CreateSnapshot.return_value = (self._FAKE_JOB_PATH,
                                                 mock.MagicMock(),
                                                 self._FAKE_RET_VAL)
 
-        self._vmutils.take_vm_snapshot(self._FAKE_VM_NAME)
+        snap_path = self._vmutils.take_vm_snapshot(self._FAKE_VM_NAME)
 
+        self.assertEqual(mock_snap.Dependent.path_.return_value, snap_path)
         mock_svc.CreateSnapshot.assert_called_with(
             AffectedSystem=self._FAKE_VM_PATH,
             SnapshotType=self._vmutils._SNAPSHOT_FULL)
@@ -938,7 +942,10 @@ class VMUtilsTestCase(test_base.OsWinBaseTestCase):
             self.assertEqual(watcher.return_value, listener)
 
     @mock.patch('time.sleep')
-    def test_vm_power_state_change_event_handler(self, mock_sleep):
+    @mock.patch.object(vmutils, 'tpool')
+    @mock.patch.object(vmutils, 'patcher')
+    def test_vm_power_state_change_event_handler(self, mock_patcher,
+                                                 mock_tpool, mock_sleep):
         self._mock_wmi.x_wmi_timed_out = exceptions.HyperVException
 
         enabled_state = constants.HYPERV_VM_STATE_ENABLED
@@ -949,9 +956,9 @@ class VMUtilsTestCase(test_base.OsWinBaseTestCase):
 
         fake_listener = (
             self._vmutils._conn.Msvm_ComputerSystem.watch_for.return_value)
-        fake_listener.side_effect = (self._mock_wmi.x_wmi_timed_out,
-                                     fake_event, Exception,
-                                     KeyboardInterrupt)
+        mock_tpool.execute.side_effect = (self._mock_wmi.x_wmi_timed_out,
+                                          fake_event, Exception,
+                                          KeyboardInterrupt)
 
         handler = self._vmutils.get_vm_power_state_change_listener(
             get_handler=True)
@@ -961,7 +968,8 @@ class VMUtilsTestCase(test_base.OsWinBaseTestCase):
 
         fake_callback.assert_called_once_with(mock.sentinel.vm_name,
                                               enabled_state)
-        fake_listener.assert_has_calls(
+        mock_tpool.execute.assert_has_calls(
+            fake_listener,
             [mock.call(self._vmutils._DEFAULT_EVENT_TIMEOUT_MS)] * 4)
         mock_sleep.assert_called_once_with(
             self._vmutils._DEFAULT_EVENT_TIMEOUT_MS / 1000)
@@ -981,6 +989,14 @@ class VMUtilsTestCase(test_base.OsWinBaseTestCase):
     def test_get_vm_generation_gen2(self):
         self._test_get_vm_generation(constants.VM_GEN_2)
 
+    def test_get_vm_generation_no_attr(self):
+        mock_settings = self._lookup_vm()
+        mock_settings.VirtualSystemSubType.side_effect = AttributeError
+
+        ret = self._vmutils.get_vm_generation(mock.sentinel.FAKE_VM_NAME)
+
+        self.assertEqual(constants.VM_GEN_1, ret)
+
     def test_stop_vm_jobs(self):
         mock_vm = self._lookup_vm()
 
